@@ -2,7 +2,7 @@ from meteor_reasoner.classes.literal import *
 from meteor_reasoner.classes.rule import *
 from meteor_reasoner.classes.atom import Atom
 from meteor_reasoner.classes.interval import Interval
-from meteor_reasoner.classes.term import Term
+
 
 def euqal_conversion(f):
     """
@@ -18,7 +18,7 @@ def euqal_conversion(f):
 
     """
     t1, t2 = f.interval.left_value, f.interval.right_value
-    head = Atom("Bottom", tuple([Term("nan")]))
+    head = Atom("Bottom", ())
     literal1 = Atom("New", f.entity)
     literal2 = Literal(Atom(f.predicate, f.entity))
     operator1 = Operator("Boxplus", Interval(0, t2-t1, False, f.interval.right_open))
